==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/ScheduleStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ScheduleStatusFluent<A extends ScheduleStatusFluent<A>> extends Fluent<A> {


    public String getNextRecover();
    public A withNextRecover(String nextRecover);
    public Boolean hasNextRecover();
    public A withNewNextRecover(StringBuilder arg1);
    public A withNewNextRecover(int[] arg1,int arg2,int arg3);
    public A withNewNextRecover(char[] arg1);
    public A withNewNextRecover(StringBuffer arg1);
    public A withNewNextRecover(byte[] arg1,int arg2);
    public A withNewNextRecover(byte[] arg1);
    public A withNewNextRecover(char[] arg1,int arg2,int arg3);
    public A withNewNextRecover(byte[] arg1,int arg2,int arg3);
    public A withNewNextRecover(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNextRecover(String arg1);
    public String getNextStart();
    public A withNextStart(String nextStart);
    public Boolean hasNextStart();
    public A withNewNextStart(StringBuilder arg1);
    public A withNewNextStart(int[] arg1,int arg2,int arg3);
    public A withNewNextStart(char[] arg1);
    public A withNewNextStart(StringBuffer arg1);
    public A withNewNextStart(byte[] arg1,int arg2);
    public A withNewNextStart(byte[] arg1);
    public A withNewNextStart(char[] arg1,int arg2,int arg3);
    public A withNewNextStart(byte[] arg1,int arg2,int arg3);
    public A withNewNextStart(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNextStart(String arg1);
}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/ScheduleStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ScheduleStatusFluent<A extends ScheduleStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getNextRecover();
    public A withNextRecover(String nextRecover);
    public Boolean hasNextRecover();
    public A withNewNextRecover(StringBuilder arg1);
    public A withNewNextRecover(int[] arg1,int arg2,int arg3);
    public A withNewNextRecover(char[] arg1);
    public A withNewNextRecover(StringBuffer arg1);
    public A withNewNextRecover(byte[] arg1,int arg2);
    public A withNewNextRecover(byte[] arg1);
    public A withNewNextRecover(char[] arg1,int arg2,int arg3);
    public A withNewNextRecover(byte[] arg1,int arg2,int arg3);
    public A withNewNextRecover(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNextRecover(String arg1);
    public String getNextStart();
    public A withNextStart(String nextStart);
    public Boolean hasNextStart();
    public A withNewNextStart(StringBuilder arg1);
    public A withNewNextStart(int[] arg1,int arg2,int arg3);
    public A withNewNextStart(char[] arg1);
    public A withNewNextStart(StringBuffer arg1);
    public A withNewNextStart(byte[] arg1,int arg2);
    public A withNewNextStart(byte[] arg1);
    public A withNewNextStart(char[] arg1,int arg2,int arg3);
    public A withNewNextStart(byte[] arg1,int arg2,int arg3);
    public A withNewNextStart(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNextStart(String arg1);
}
